w_adjust=0; //0 for 5/8" feeders, 3 for 3/4" feeders
l_adjust=0; //0 for east, 50 for west


module tape_cog(){
	spacing=4; //tape holes 4mm apart
	teeth=36; // number of teeth on circumference
	circum=spacing*teeth;
	dia=circum/3.1415926;
	rad=dia/2;
	axel=25.4*.125;
	bit=25.4*(.125/2);

	difference(){	
		union(){
			cylinder(h=1,r=rad,center=true,$fn=100);
				for ( i = [0 : teeth-1] ) {
					rotate( i * 360 / teeth+(360/(teeth*2)), [0, 0, 1])
				    	translate([0, rad, 0])
			    		tooth(1);
				}		
		}
		cylinder(h=10,r=axel,center=true,$fn=20);
		for ( i = [0 : teeth-1] ) {
			rotate( i * 360 / teeth, [0, 0, 1])
		    	translate([0, rad+.7, 0])
	    		cylinder(h=2,r=bit,center=true,$fn=20);
		}		
	}
		

}
module tooth(t){
		intersection(){
			translate([.45,.1,0]) cylinder(h=t,r=1,center=true,$fn=40);
			translate([-.45,.1,0]) cylinder(h=t,r=1,center=true,$fn=40);

		}

}

module sidepanel(t_thick, t_width, pe_thick, g_length)
{
	difference(){
		union(){
			translate([g_length/2-30,0,-pe_thick*2-10]) cube([g_length,1.2,pe_thick*2],center=true);

//			translate([0,0,8]) cube([60,1.2,50],center=true);			
			translate([0,0,7]) cube([60,1.2,2.75*25.4],center=true); //gantry Z clearance height
//			color("DimGray")  translate([0,0,28]) cube([5,2,1],center=true);
		}
		screw_holes();

	}
}




module screw_holes(){
	bot=-27;
	for(i = [ 	[ 0,  0,  0],		//axel
           		[19,0,32],		//screws for worm support
			[7.5,0,32],		//screws for worm support
			[-26,0,32],		//screws for motor mount
			[-18.5,0,32],	//screws for motor mount
			[25,0,bot],		//screws for bottom
			[-25,0,bot],		//screws for bottom
		        [80+l_adjust,0,bot] ])		//screws for bottom
	{
	    translate(i) rotate([90,0,0]) cylinder(h=5,r=1.65,center=true,$fn=20);
	}
	//windows (temp)
	for(i = [ 	[ -18,  0,  -16],		
           		[18,0,-16],		
           		[0,0,-22],		
		        [0,0,12] ])		
	{
	    translate(i) rotate([90,0,0]) cylinder(h=5,r=5,center=true,$fn=20);
	}


}

module screws_cones(){

	r1=.112*25.4/2;
	r2=.212*25.4/2;
	h=.064*25.4;
	s=12;
	bot=-27;

	for(i = [ 	[ 0,  0,  0],		//axel
           		[19,0,32],		//screws for worm support
			[7.5,0,32],		//screws for worm support
			[-26,0,32],		//screws for motor mount
			[-18.5,0,32],	//screws for motor mount
			[25,0,bot],		//screws for bottom
			[-25,0,bot],		//screws for bottom
		        [80+l_adjust,0,bot] ])		//screws for bottom
	{
		translate(i) rotate([90,0,0]) 	cylinder(h=s,r=r1*.75,center=true,$fn=20);
		translate(i) translate([0,.7,0]) rotate([90,0,0]) cylinder(h=h,r1=r1,r2=r2,center=true,$fn=20);
		translate(i) translate([0,-.7,0]) rotate([90,0,0]) cylinder(h=h,r1=r2,r2=r1,center=true,$fn=20);
	}

}




module motor(){
//			translate([0,0,-38]) cylinder(r=17/2,h=32.6+22.7,center=true); //test of kysan planetary motor
//			translate([0,0,-18]) cylinder(r=12/2,h=28,center=true); //test of ebay planetary motor


//			translate([0,0,-9]) cube([12,10,11], center=true); 	//small kysan motors
//			translate([0,0,-22]) intersection(){				//small kysan motors
//				cube([18,10,15], center=true);				//small kysan motors
//				cylinder(r=12/2,h=15,center=true);		//small kysan motors
//			}											//small kysan motors

			translate([0,0,-9]) cube([13,12,11], center=true); 	//ebay motor
			translate([0,0,-28]) intersection(){				//ebay motor
				cube([18,12,27], center=true);				//ebay motor
				cylinder(r=15.5/2,h=27,center=true);		//ebay motor
			}											//ebay motor

}


module motor_mount(){
	clearance=.25;
	difference(){
		union(){
			translate([-2,0,-4]) cube([36,16,16],center=true);
			translate([-14,-w_adjust/2,9]) cube([12,16+w_adjust,26],center=true);
		}
		union(){
			cube([13+clearance,12+clearance,11], center=true);
			intersection(){
					cube([18,12+clearance,27], center=true);
					cylinder(r=15.5/2+clearance,h=27,center=true);//15.5
			}
			rotate([0,0,0]) {
				translate([10,0,0]) cube([15,2,10],center=true);
				translate([11,4.5,0]) rotate([90,0,0]) cylinder(h=9,r=1.5,$fn=20,center=true);
				translate([11,-4.5,0]) rotate([90,0,0]) cylinder(h=9,r=2,$fn=20,center=true);
				translate([11,-8,0]) rotate([90,0,0]) cylinder(h=4.5,r=3,$fn=20,center=true);
				translate([11,-4.2,0]) rotate([90,0,0]) cylinder(h=3,r1=1.5,r2=3,$fn=20,center=true);
				translate([0,0,-8]) {
					translate([10,0,0]) cube([15,2,10],center=true);
					translate([11,4.5,0]) rotate([90,0,0]) cylinder(h=9,r=1.5,$fn=20,center=true);
					translate([11,-4.5,0]) rotate([90,0,0]) cylinder(h=9,r=2,$fn=20,center=true);
					translate([11,-8,0]) rotate([90,0,0]) cylinder(h=4.5,r=3,$fn=20,center=true);
					translate([11,-4.2,0]) rotate([90,0,0]) cylinder(h=3,r1=1.5,r2=3,$fn=20,center=true);
				}

			}
		}
	}
}

module circuit_board(t_thick, t_width, pe_thick, g_length)
{
len=55.5;
	difference(){
		union(){
			cube([len,16,1.4],center=true);
			translate([-len/2+14.5,8.6,0]) cube([6.75,3.2,3.2],center=true);//bottom slot +1 (trim for tight fit of board)
			translate([-len/2+14.5,-8.6,0]) cube([6,1.2,1.4],center=true);	
	
			translate([9,8.6,0]) cube([6.75,3.2,3.2],center=true);//top slot (trim for tight fit of board, 7 is sloppy
			translate([9,-8.6,0]) cube([6,1.2,1.4],center=true);

			color("DimGray") {
				translate([-len/2+14.5,8.6,.7+2.5]) cube([4.75,3.2,5.7],center=true);	//hole for block, added .5mm for clearance
	
				translate([-len/2+14.5,8.6-2.25,1.4]) cube([4,5.7,1.2],center=true);		

				translate([-len/2+14.5,8.6-3.25-1.2,.7+2.5]) cube([4,1.2,4.2],center=true);		
			}
	
		}
	}
}
module circuit_board_holes(){
	
	difference(){
		union(){
			translate([-2,-7,0]) cube([32,3,7],center=true);
			translate([-13.25,-8,0]) cube([3,5,2.5],center=true);
			translate([8.75,-8,0]) cube([3,5,2.5],center=true);
			translate([-11.5,-8,0]) rotate([90,0,0]) cylinder(h=5,r=1.25,$fn=10,center=true);
			translate([10.75,-8,0]) rotate([90,0,0]) cylinder(h=5,r=1.25,$fn=10,center=true);
			translate([-15,-8,0]) rotate([90,0,0]) cylinder(h=5,r=1.25,$fn=10,center=true);
			translate([7,-8,0]) rotate([90,0,0]) cylinder(h=5,r=1.25,$fn=10,center=true);
		}
			translate([0,2.25,0]) scale([1,1,1.25]) circuit_board();
	}
}


module worm_support(){
	difference(){
		union(){
			//cube([10,10,10],center=true);
			translate([5,-1.5,-2.5]) cube([20,12,15],center=true);
			translate([14,-w_adjust/2,0]) cube([12,16+w_adjust,20],center=true);//base
		}
		cylinder(h=15,r=2.55/2,$fn=20,center=true);//spring steel hole
		translate([0,-7.3-w_adjust,0]) cube([45,1.5,45],center=true);//raft slicer block

	}
} 

module sidepanel_w_hook(t_thick, t_width, pe_thick, g_length)
{
	difference(){
		union(){
			translate([g_length/2+l_adjust/2-30,0,-pe_thick*2-10.5]) cube([g_length+l_adjust,1.2,pe_thick*2],center=true);
			translate([0,0,5]) cube([60,1.2,2.75*25.4],center=true); //gantry Z clearance height
			intersection(){
				translate([g_length+l_adjust-30,0,-pe_thick*2-22]) rotate([90,0,0]) cylinder(h=1.2,r=15,$fn=20,center=true);
				translate([g_length+l_adjust-20,0,-pe_thick*2-20]) cube([20,1.2,30],center=true);
			}
		}
		union(){
			intersection(){
				translate([g_length+l_adjust-30,0,-pe_thick*2-24.25]) 
					rotate([90,0,0]) cylinder(h=10,r=25.4/4+.5,$fn=20,center=true);
				translate([g_length+l_adjust-20,0,-pe_thick*2-22]) cube([20,10,20],center=true);
			}
			screw_holes();
		}

	}
}


module test(){
t_thick=2;
t_width=8;
pe_thick=6;
g_length=135;
width=18;
worm_offset=17;

//	difference(){
//		color("DimGray") tapeguide_top(t_thick, t_width, pe_thick, g_length);
//		translate([0,width/1.8,0]) screws_cones();
//		translate([0,-width/2,0]) screws_cones();
//	}
	color("DimGray") tapeguide2(t_thick, t_width, pe_thick, g_length);
}
module wormgear3(){

	difference(){
		union(){
			cylinder(h=25.4/4,r=25.4/2,center=true,$fn=24);
			cylinder(h=12,r=8,center=true,$fn=20);
		}
		union(){
			translate([0,0,-5]) cylinder(h=35,r=25.4/8,center=true,$fn=20);
		}
	}
}

module worm3(){

	difference(){
		union(){
			cylinder(h=19.5,r=25.4/4,center=false,$fn=20);
			translate([0,0,-3]) cylinder(h=3,r=25.4/4,center=false,$fn=20);	

		}
		union(){
			translate([0,0,-3.5]) cylinder(h=10,r=1.5,center=false,$fn=20);
			translate([0,0,6]) cylinder(h=20,r=2,center=false,$fn=20);
			translate([3.25,0,0]) rotate([0,90,0]){
				 cylinder(h=2,r=3.125,center=true,$fn=6);
				 cylinder(h=8,r=1.5,center=true,$fn=12);
				translate([1.5,0,0]) cube([3.125,5.5,2],center=true);
				}

		}
	}
}

module tapeguide2(t_thick, t_width, pe_thick, g_length)
{
	clearance=.25;
	width=16.5+w_adjust; //18, but subtract 1.5 for raft
	
//	%translate([0,width/2-2.5,0]) rotate([90,0,0]) tape_cog();

	difference(){
		translate([0,.5,-22]) 
			union(){
				translate([g_length/2-30+l_adjust/2,0,-1]) cube([g_length-.02+l_adjust,width-1.99,15], center=true);//main block
				translate([-30+10,0,6]) cube([20,width-2,24], center=true);//main block extension
			}
		union(){
			for(z=[1:t_thick])
				translate([0,width/2-t_width/2-clearance*2,z*-1+1.25]) //(was +1 before testing)
					scale([1.01,1,1.01])
					rotate([90,0,180]) 
					linear_extrude(file = "tape path2.dxf", layer = "tape_path",  height = t_width+clearance*4, center = true, convexity = 20, twist = 0);
				translate([0,width/2-t_width/2-clearance*2,-.25]) //hack to make slot slightly wider (was .55 before testing(-.55?))
					scale([1.01,1,1.01])
					rotate([90,0,180]) 
					linear_extrude(file = "tape path2.dxf", layer = "tape_path",  height = t_width+clearance*4, center = true, convexity = 20, twist = 0);
			translate([0,width/2-2.5,0]) rotate([90,0,0]) cylinder(h=1.25,r=25,center=true); //wheel clearance
			translate([0,width/2,0]) rotate([90,0,0]) cylinder(h=4,r=25,center=true); //visibility and printability
			translate([19,width/2-1.125,-18]) rotate([0,35,0]) cube([5,4,1.1],center=true); //fix tape catching		
			translate([18,width/2-1.125,-18]) rotate([0,35,0]) cube([4,4,1.1],center=true); //fix tape catching		
			translate([17,width/2-1.125,-18]) rotate([0,45,0]) cube([4,4,1.1],center=true); //fix tape catching		
			translate([16,width/2-1.125,-18]) rotate([0,45,0]) cube([4,4,1.1],center=true); //fix tape catching		
			translate([15,width/2-1.125,-18]) rotate([0,45,0]) cube([4,4,1.1],center=true); //fix tape catching		
			translate([0,0,0]) rotate([90,0,0]) cylinder(h=30,r=14.5,center=true); //wormgear clearance
		}
		translate([g_length-22-t_width*1.5+l_adjust,(width)/2-t_width/2,-17]) cube([t_width*2,t_width+clearance,5],center=true);//pick hole
		translate([0,-width/4+1-w_adjust/2,-16]) rotate([45,0,0]) cube([75,4,4],center=true);//cover tape hole
		translate([0,-width/4-2-w_adjust/2,-22]) rotate([45,0,0]) cube([90,2,2],center=true);//wire route
		translate([45,-width/4-2-w_adjust/2,-19]) rotate([45,90,0]) cube([10,2,2],center=true);//wire route
	}
}



module main(){
t_thick=2;
t_width=8;
pe_thick=7;
g_length=135;
width=18;
worm_offset=18;

	translate([0,4.5,0]){
		color("silver") translate([0,2.5,0]) rotate([90,360*$t,0]) tape_cog();
//		%translate([$t*-24*4+2+42,0,-22.7]) rotate([0,0,0]) tape(t_width, t_thick);
	}

	color("DimGray") translate([-12,0,worm_offset]) rotate([0,90,0])  worm3();	
	color("DimGray") translate([-12,0,worm_offset]) rotate([0,90,0])  motor();	
	difference(){
		color("DimGray") translate([13,0,worm_offset]) rotate([0,-90,0])  worm_support();	
		translate([0,width/2,0]) screws_cones();
		translate([0,-width/2-w_adjust,0]) screws_cones();
	}
	difference(){
		color("DimGray") translate([-34.5,0,worm_offset]) rotate([0,90,0])  motor_mount();
		translate([0,width/2,0]) screws_cones();
		translate([0,-width/2-w_adjust,0]) screws_cones();
	}




	
	color("DimGray") translate([0,0,0]) rotate([90,360,0]) wormgear3();

	difference(){
		color("DimGray") tapeguide2(t_thick, t_width, pe_thick, g_length);
		translate([0,width/2,0]) screws_cones();
		translate([0,-width/2,0]) screws_cones();
	}
	%difference(){
		color("Gainsboro") translate([0,width/2,0]) sidepanel_w_hook(t_thick, t_width, pe_thick, g_length);
		translate([27,.5,12]) rotate([0,-90,0]) circuit_board();	
	}
//	%difference(){
//		color("Gainsboro") translate([0,-width/2+.8,0]) sidepanel_w_hook(t_thick, t_width, pe_thick, g_length);
//		translate([27,.3,12]) rotate([0,-90,0]) circuit_board();
//	}

	color("OliveDrab") translate([27,.4,12]) rotate([0,-90,0]) circuit_board();//was 26.5

}
module print(){
t_thick=1;
t_width=8;
pe_thick=6.5;
g_length=135;
width=16.5;//-1.5 for raft
worm_offset=18;


//	translate([0,4.5,0]){
//		color("silver") translate([0,2.5,0]) rotate([90,360*$t,0]) tape_cog();
//		%translate([$t*-24*4+2+42,0,-22.7]) rotate([0,0,0]) tape(t_width, t_thick);
//	}

//	color("DimGray") translate([-12,0,worm_offset]) rotate([0,90,0])  worm3();	
//	color("DimGray") translate([-12,0,worm_offset]) rotate([0,90,0])  motor();	
//	difference(){
//		color("DimGray") translate([13,0,worm_offset]) rotate([0,-90,0])  worm_support();	
//		translate([0,width/2,0]) screws_cones();
//		translate([0,-width/2-w_adjust,0]) screws_cones();
//	}
//	difference(){
//		color("DimGray") translate([-34.5,0,worm_offset]) rotate([0,90,0])  motor_mount();
//		translate([0,width/2,0]) screws_cones();
//		translate([0,-width/2-w_adjust,0]) screws_cones();
//	}




	
//	color("DimGray") translate([0,0,0]) rotate([90,360,0]) wormgear3();

	difference(){
		color("DimGray") tapeguide2(t_thick, t_width, pe_thick, g_length);
		translate([0,width/2,0]) screws_cones();
		translate([0,-width/2+1.5,0]) screws_cones();
	}
//	 projection(cut=true) {
//		translate([0,0,-8.5]) rotate([90,0,0])  difference(){
//			color("Gainsboro") translate([0,width/2,0]) sidepanel_w_hook(t_thick, t_width, pe_thick, g_length);
//			translate([26.5,.5,12]) rotate([0,-90,0]) circuit_board();	
//		}
//		translate([90+l_adjust,-32,-8.5]) rotate([-90,180,0])  difference(){
//			color("Gainsboro") translate([0,width/2,0]) sidepanel_w_hook(t_thick, t_width, pe_thick, g_length);
//			translate([27,.5,12]) rotate([0,-90,0]) circuit_board();	
//		}
//	}
//	difference(){
//		color("Gainsboro") translate([0,-width/2+.8,0]) sidepanel_w_hook(t_thick, t_width, pe_thick, g_length);
//		translate([27,.3,12]) rotate([0,-90,0]) circuit_board();
//	}

//	color("OliveDrab") translate([27,.4,12]) rotate([0,-90,0]) circuit_board();//was 26.5
//	color("OliveDrab") translate([27,1+w_adjust,12]) rotate([0,-90,0]) circuit_board();//was 26.5
//	circuit_board_holes();
}


main();
//print();
//test();


//screws_cones();
//motor_mount();
//worm_support();
//circuit_board();
//projection(cut=true) circuit_board();
//tape_cog();
//projection(cut=true) tape_cog();
//projection(cut=true) wormgear();
//wormgear3();
//worm3();
//tooth();
//translate([0,2.5,8.1]) rotate([90,0,0]) tape_cog();
//translate([2,0,0]) rotate([0,0,0]) tape();
//acme_thread();
